pub struct Journal {
pub version: u32,
pub entries: Vec<JournalEntry>,
}Fields
version: u32entries: Vec<JournalEntry>Implementations
Sourceimpl Journal
impl Journal
pub fn empty() -> Self
pub fn add_entry(&mut self, name: &str, hash: &str)
pub fn next_migration_number(&self) -> u32
pub fn latest_snapshot_name_owned(&self) -> Option<String>
Sourcepub fn read_from_path(path: &str) -> Result<Self, DbCoreError>
pub fn read_from_path(path: &str) -> Result<Self, DbCoreError>
Reads a journal from a JSON file, returning an empty journal if the file does not exist.
Errors
Returns DbCoreError::JournalRead if the file exists but cannot be read or parsed.
Sourcepub fn write_to_path(&self, path: &str) -> Result<(), DbCoreError>
pub fn write_to_path(&self, path: &str) -> Result<(), DbCoreError>
Writes the journal to a JSON file.
Errors
Returns DbCoreError::JournalWrite if serialization or file writing fails.