Core types for table relations used by relational query building.
Public API
RelationKind,JoinColumn,ThroughDef,RelationDefRelationRegistry, helpersone,many,many_through
Structs
- Join
Column - A single column pair in a join condition.
- Relation
Def - A complete relation definition between two tables.
- Relation
Registry - Registry of relation definitions, keyed by source table name.
- Through
Def - Configuration for many-to-many relations via a junction table.
Enums
- Relation
Kind - The kind of relation between two tables.
Functions
- many
- Create a
Many(has-many) relation. - many_
through - Create a
Manyrelation through a junction table (many-to-many). - one
- Create a
One(belongs-to / has-one) relation.