pub struct Snapshot {
pub version: u32,
pub dialect: String,
pub id: String,
pub prev_id: String,
pub tables: BTreeMap<String, SnapshotTable>,
pub enums: BTreeMap<String, SnapshotEnum>,
pub meta: SnapshotMeta,
}Fields
version: u32dialect: Stringid: Stringprev_id: Stringtables: BTreeMap<String, SnapshotTable>enums: BTreeMap<String, SnapshotEnum>meta: SnapshotMetaImplementations
Sourceimpl Snapshot
impl Snapshot
pub fn empty() -> Self
pub fn from_registry(registry: &SchemaRegistry) -> Self
pub fn to_registry(&self) -> SchemaRegistry
Sourcepub fn read_from_path(path: &str) -> Result<Self, DbCoreError>
pub fn read_from_path(path: &str) -> Result<Self, DbCoreError>
Reads a snapshot from the given path. Returns an empty snapshot if the file does not exist.
Errors
Returns DbCoreError::SnapshotRead if the file exists but cannot be read or parsed.
Sourcepub fn write_to_path(&self, path: &str) -> Result<(), DbCoreError>
pub fn write_to_path(&self, path: &str) -> Result<(), DbCoreError>
Writes the snapshot to the given path as pretty-printed JSON.
Errors
Returns DbCoreError::SnapshotWrite if the file cannot be written.